# Planned future work

This is the stuff I plan to add in future releases. Please feel free to open an issue
discussing a usecase if it is not yet added in the following list:

- [ ] Better integration with dataclasses through `field`s
- [ ] Integration with `typing.Annotated` ([docs](https://docs.python.org/3/library/typing.html#typing.Annotated))
